conttablehm: returns a data.frame of summary statistics on a time variable...

Description Usage

View source: R/conttablehm.R

Description

returns a data.frame of summary statistics on a time variable y that is in fractional hours and converts to HH:MM; good for exporting/usine elsewhere

Usage

1
conttablehm(y, mydigits = 1)

AndrewH6/BioCG documentation built on Dec. 17, 2021, 8:50 a.m.