returns a data.frame of summary statistics on a time variable y that is in fractional hours and converts to HH:MM; good for exporting/usine elsewhere
1 | conttablehm(y, mydigits = 1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.